# #3

### General Details

Run Date: 2021-02-05 15:40:09
Period: 2021-02-05 15:40:09 - 2021-02-05 15:42:09
Run Duration: 2 minutes, 0 second
Status: FAILED
Author: Guillaume Bert

### Description/Conclusion

### Workload Characteristics

Max Running Users:
Average Hits per Second: 239.12138
Total Hits: 14524
Total Passed Transactions per Second: 119.49827
Total Transactions (Success): 152
Total Transactions (Failed): 14205

### Transactions

Name | Count | TPS | Min Dur | Avg Dur | Max Dur | Total | Success | Fail | p50 | p90 | p95 | p99
⚠ kamoulox \ Actions \ transaction_sla_passed | 780 | 31.2 | 0.058 | 0.073 | 0.202 | 780 | 9 | 771 | 0.074 | 0.077 | 0.078 | 0.079

### Ext. Data

No external data in this test.

### Running Vitrual Users

### Hits per Second